/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XPNfi for the 5D integration at all eps-orders of the pseudo-nf structure. 
 * Example: PNfI5EM1y ('P'seudo-'Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st order, only missing integration over 'y' or its rescaled version) 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XPNf functions to arrive at eps^-1. 
 * Starting from eps^-1 (1 deltas) we need no eps power, so only XPNf0 and no logs appear
 */

#include <5IntPNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorPNf.h>
#include <Input_Common.h>
using namespace std;

// additional integrations run over y (x after rescaling), t5 (s5 after rescaling)

double PNfI5EM1u(double w,double s6,double x,double s5,double c) {
	return 0;
}

double PNfI5E0u(double w,double s6,double x,double s5,double c) {
	return pow(s5,-1)*pow(x,-1)*((-log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA1(v(w),tl(s6),y(x),0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),y(x),0,0,b(c))) -
	        log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),y(x),0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XPNf0(w,s6,0,0,c) +
	     (log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c))) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c))) +
	        log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c))) + log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c))))*XPNf0(w,s6,s5,0,c)
	     );
}

// additional integrations run over y (x after rescaling), u (z after rescaling)

double PNfI5EM1t(double w,double s6,double x,double z,double c) {
	return 0;
}

double PNfI5E0t(double w,double s6,double x,double z,double c) {
	return -2*pow(x,-1)*pow(z,-1)*((log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA1(v(w),tl(s6),y(x),0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),y(x),0,0,b(c))) +
	        log(FB1(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),y(x),0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))) - log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XPNf0(w,s6,0,0,c) +
	     (-log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA1(v(w),tl(s6),y(x),0,u(z),b(c))) - log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),y(x),0,u(z),b(c))) -
	        log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),y(x),0,u(z),b(c))) - log(FB2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),y(x),0,u(z),b(c))))*XPNf0(w,s6,0,z,c));
}

// additional integrations run over t5 (s5 after rescaling), u (z after rescaling)

double PNfI5EM1y(double w,double s6,double s5,double z,double c) {
	return 2*pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*pow(z,-1)*(XPNf0(w,s6,0,0,c) - XPNf0(w,s6,0,z,c) - XPNf0(w,s6,s5,0,c) + XPNf0(w,s6,s5,z,c));
}

double PNfI5E0y(double w,double s6,double s5,double z,double c) {
	return -2*pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*pow(z,-1)*((2*log(s5) + 4*log(z) - log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) -
	        log(FB2(v(w),tl(s6),0,0,0,b(c))))*XPNf0(w,s6,0,0,c) + (-2*log(s5) - 4*log(z) + log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),0,0,u(z),b(c))) +
	        log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),0,0,u(z),b(c))))*XPNf0(w,s6,0,z,c) - 2*log(s5)*XPNf0(w,s6,s5,0,c) - 4*log(z)*XPNf0(w,s6,s5,0,c) +
	     log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf0(w,s6,s5,0,c) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf0(w,s6,s5,0,c) + log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf0(w,s6,s5,0,c) +
	     log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XPNf0(w,s6,s5,0,c) + 2*log(s5)*XPNf0(w,s6,s5,z,c) + 4*log(z)*XPNf0(w,s6,s5,z,c) - log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XPNf0(w,s6,s5,z,c) -
	     log(FA2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XPNf0(w,s6,s5,z,c) - log(FB1(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XPNf0(w,s6,s5,z,c) - log(FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XPNf0(w,s6,s5,z,c) -
	     XPNf1(w,s6,0,0,c) + XPNf1(w,s6,0,z,c) + XPNf1(w,s6,s5,0,c) - XPNf1(w,s6,s5,z,c));
}
