/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEi for the 4D integration at all eps-orders of the Cf^2 structure, subregion a. 
 * Example: I4EM1rx ('I'ntegration over '4' dimensions, at 'E'ps to the 'M'inus '1'st order, third and fourth integrations over 'r' and 'x') contains various logs of FXi functions
 * evaluated at c=0,s5=0, i.e. with the two deltas from the c and s5 +-distributions, multiplied with the correct X functions' eps-powers to arrive at eps^-1. 
 */

#include <4Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I4EM2rx(double r, double x, double s, double s6) {
	return 0; //no alpha-poles, but leading order is xi-indep
}
double I4EM1rx(double r, double x, double s, double s6) {
	return (pow(r,-1)*pow(x,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	          log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
	          log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),0)) +
	          log(FA2b(q(r),y(x),t(s),0,tl(s6),0)))*XCfE0(s,0,s6) + XCfE1(0,0,s,0,s6) - XCfE1(0,x,s,0,s6) - XCfE1(r,0,s,0,s6) + XCfE1(r,x,s,0,s6)))/2.;
}
double I4E0rx(double r, double x, double s, double s6) {
	return (pow(r,-1)*pow(x,-1)*((mexp*n*log(r)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
            log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
            log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),0)) +
            log(FA2b(q(r),y(x),t(s),0,tl(s6),0))) + 2*(mexp*n*log(x)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) +
               log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
               log(FA2a(0,y(x),t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) -
               log(FA2b(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),y(x),t(s),0,tl(s6),0))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(q(r),y(x),t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(q(r),y(x),t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),y(x),t(s),0,tl(s6),0)),2)))*XCfE0(s,0,s6) +
      (mexp*n*(log(r) + 2*log(x)) + log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) -
      (mexp*n*(log(r) + 2*log(x)) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE1(0,x,s,0,s6) -
      (mexp*n*(log(r) + 2*log(x)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE1(r,0,s,0,s6) +
      (mexp*n*(log(r) + 2*log(x)) + log(FA1a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA1b(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2a(q(r),y(x),t(s),0,tl(s6),0)) + log(FA2b(q(r),y(x),t(s),0,tl(s6),0)))*XCfE1(r,x,s,0,s6) +
      XCfE2(0,0,s,0,s6) - XCfE2(0,x,s,0,s6) - XCfE2(r,0,s,0,s6) + XCfE2(r,x,s,0,s6)))/2.;
}

double I4EM2rc(double c, double r, double s, double s6) {
	return 0; //one alpha pole, which can be cancelled, but not converted
}
double I4EM1rc(double c, double r, double s, double s6) {
	return (-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) -
		     log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
		     log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
		     log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) -
		     log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(q(r),0,t(s),0,tl(s6),0)) -
		     log(FA2b(q(r),0,t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(n,-1)*pow(r,-1)*XCfE0(s,0,s6);
}
double I4E0rc(double c, double r, double s, double s6) {
	return pow(c,-1)*pow(mexp,-1)*pow(n,-1)*pow(r,-1)*((mexp*n*log(r)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) +
	           log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) -
	           log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) -
	           log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),b(c)))) +
	        4*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) +
	           log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) -
	           log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(q(r),0,t(s),0,tl(s6),0)) +
	           log(FA2b(q(r),0,t(s),0,tl(s6),b(c)))) - 2*(pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) -
	           pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(q(r),0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) -
	           pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),0,t(s),0,tl(s6),b(c))),2) +
	           pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) +
	           pow(log(FA2a(q(r),0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2) -
	           pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),0,t(s),0,tl(s6),b(c))),2)))*XCfE0(s,0,s6) +
	     (-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) -
	        log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))))*
	      XCfE1(0,0,s,0,s6) + (log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),b(c))) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) -
	        log(FA1b(q(r),0,t(s),0,tl(s6),b(c))) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),b(c))) +
	        log(FA2b(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),b(c))))*XCfE1(r,0,s,0,s6));
}

double I4EM2rs(double r, double s, double s5, double s6) {
	return 0; // one alpha pole, but leading order is r-indep
}
double I4EM1rs(double r, double s, double s5, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(r,-1)*pow(s5,-1)*((-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) -
	          log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
	          log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
	       (log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) -
	          log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) +
	          log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6) - XCfE1(0,0,s,0,s6) +
	       XCfE1(0,0,s,s5,s6) + XCfE1(r,0,s,0,s6) - XCfE1(r,0,s,s5,s6)))/2.;
}
double I4E0rs(double r, double s, double s5, double s6) {
	return pow(r,-1)*pow(s5,-1)*((log(r)*((-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2a(q(r),0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
         (log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
            log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6)))/2. - (log(r)*XCfE1(0,0,s,0,s6))/2. +
    (log(r)*XCfE1(0,0,s,s5,s6))/2. + (log(r)*XCfE1(r,0,s,0,s6))/2. - (log(r)*XCfE1(r,0,s,s5,s6))/2.) +
 pow(mexp,-1)*pow(n,-1)*pow(r,-1)*pow(s5,-1)*((log(s5)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(q(r),0,t(s),0,tl(s6),0)) +
          log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(q(r),0,t(s),0,tl(s6),0))) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
       pow(log(FA1a(q(r),0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(q(r),0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) +
       pow(log(FA2a(q(r),0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(q(r),0,t(s),0,tl(s6),0)),2))*XCfE0(s,0,s6) +
    (log(s5)*(-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
          log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0))) + pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) -
       pow(log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) -
       pow(log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)),2))*XCfE0(s,s5,s6) +
    ((2*log(s5) - log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6))/2. +
    ((-2*log(s5) + log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1(0,0,s,s5,s6))/2. +
    ((-2*log(s5) + log(FA1a(q(r),0,t(s),0,tl(s6),0)) + log(FA1b(q(r),0,t(s),0,tl(s6),0)) + log(FA2a(q(r),0,t(s),0,tl(s6),0)) + log(FA2b(q(r),0,t(s),0,tl(s6),0)))*XCfE1(r,0,s,0,s6))/2. +
    ((2*log(s5) - log(FA1a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA1b(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA2a(q(r),0,t(s),t5(s5),tl(s6),0)) - log(FA2b(q(r),0,t(s),t5(s5),tl(s6),0)))*XCfE1(r,0,s,s5,s6))/2. -
    XCfE2(0,0,s,0,s6)/2. + XCfE2(0,0,s,s5,s6)/2. + XCfE2(r,0,s,0,s6)/2. - XCfE2(r,0,s,s5,s6)/2.);
}

double I4EM2xc(double c, double x, double s, double s6) {
	return 0; //leading order is x-indep
}
double I4EM1xc(double c, double x, double s, double s6) {
	return -2*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
		     log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) -
		     log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) +
		     log(FA2b(0,y(x),t(s),0,tl(s6),b(c))))*pow(c,-1)*pow(mexp,-1)*pow(n,-1)*pow(x,-1)*XCfE0(s,0,s6);
}
double I4E0xc(double c, double x, double s, double s6) {
	return 2*pow(c,-1)*pow(mexp,-1)*pow(n,-1)*pow(x,-1)*(2*(mexp*n*log(x)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) -
	           log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) - log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),b(c)))) +
	        2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	           log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) -
	           log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,y(x),t(s),0,tl(s6),0)) +
	           log(FA2b(0,y(x),t(s),0,tl(s6),b(c)))) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) -
	        pow(log(FA1a(0,y(x),t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) -
	        pow(log(FA1b(0,y(x),t(s),0,tl(s6),b(c))),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) -
	        pow(log(FA2a(0,y(x),t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2) -
	        pow(log(FA2b(0,y(x),t(s),0,tl(s6),b(c))),2))*XCfE0(s,0,s6) + (-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) -
	        log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE1(0,0,s,0,s6) +
	     (log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) -
	        log(FA2a(0,y(x),t(s),0,tl(s6),b(c))) + log(FA2b(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),b(c))))*XCfE1(0,x,s,0,s6));
}

double I4EM2xs(double x, double s, double s5, double s6) {
	return 0; //leading order is x-indep
}
double I4EM1xs(double x, double s, double s5, double s6) {
	return pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*pow(x,-1)*((-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) -
	        log(FA2a(0,0,t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
	     (log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) -
	        log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6) - XCfE1(0,0,s,0,s6) + XCfE1(0,0,s,s5,s6) + XCfE1(0,x,s,0,s6) -
	     XCfE1(0,x,s,s5,s6));
}
double I4E0xs(double x, double s, double s5, double s6) {
	return pow(s5,-1)*pow(x,-1)*(-2*log(x)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
            log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
         (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
            log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6)) - 2*log(x)*XCfE1(0,0,s,0,s6) + 2*log(x)*XCfE1(0,0,s,s5,s6) +
      2*log(x)*XCfE1(0,x,s,0,s6) - 2*log(x)*XCfE1(0,x,s,s5,s6)) + pow(mexp,-1)*pow(n,-1)*pow(s5,-1)*pow(x,-1)*
    (2*((log(s5)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
               log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,y(x),t(s),0,tl(s6),0))) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1a(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,y(x),t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,y(x),t(s),0,tl(s6),0)),2) -
            pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2b(0,y(x),t(s),0,tl(s6),0)),2))*XCfE0(s,0,s6) +
         (log(s5)*(-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) -
               log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0))) +
            pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)),2) +
            pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) - pow(log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)),2))*XCfE0(s,s5,s6))\
       + (2*log(s5) - log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) +
      (-2*log(s5) + log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1(0,0,s,s5,s6) +
      (-2*log(s5) + log(FA1a(0,y(x),t(s),0,tl(s6),0)) + log(FA1b(0,y(x),t(s),0,tl(s6),0)) + log(FA2a(0,y(x),t(s),0,tl(s6),0)) + log(FA2b(0,y(x),t(s),0,tl(s6),0)))*XCfE1(0,x,s,0,s6) +
      (2*log(s5) - log(FA1a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA1b(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2a(0,y(x),t(s),t5(s5),tl(s6),0)) - log(FA2b(0,y(x),t(s),t5(s5),tl(s6),0)))*XCfE1(0,x,s,s5,s6) -
      XCfE2(0,0,s,0,s6) + XCfE2(0,0,s,s5,s6) + XCfE2(0,x,s,0,s6) - XCfE2(0,x,s,s5,s6));
}

double I4EM2cs(double c, double s, double s5, double s6) {
	return 0; //leading order c-indep
}
double I4EM1cs(double c, double s, double s5, double s6) {
	return 2*pow(c,-1)*pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	        log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE0(s,0,s6) +
	     (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) -
	        log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0(s,s5,s6));
}
double I4E0cs(double c, double s, double s5, double s6) {
	return 2*pow(c,-1)*pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(-2*(2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	           log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) +
	        log(s5)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) -
	           log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) +
	           log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) -
	        pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) +
	        pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0(s,0,s6) +
	     2*(2*log(c)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) -
	           log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) +
	           log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c)))) +
	        log(s5)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) -
	           log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) +
	           log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c)))) - pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) +
	        pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))),2))*XCfE0(s,s5,s6) +
	     (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
	        log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*
	      XCfE1(0,0,s,0,s6) + (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) -
	        log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE1(0,0,s,s5,s6));
}

