/*This file is part of SoftSERVE.
 *
 *   SoftSERVE is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   SoftSERVE is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with SoftSERVE.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEi for the 3D integration at all eps-orders of the Cf^2 structure, subregion b. 
 * Example: I3EM2k ('I'ntegration over '3' dimensions, at 'E'ps to the 'M'inus '2'nd order, third integration over x'k') contains various logs of FXi functions
 * evaluated at xl=0,c=0,s5=0, i.e. with all the deltas from +-distributions except the one associated with x'k', multiplied with the correct X functions' eps-powers to arrive at eps^-2. 
 */

#include <3Int.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

double I3EM3k(double xk, double s, double s6) {
	return 0; //leading order indep
}
double I3EM2k(double xk, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xk,-1)*(2*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) +
	          log(FB2(yk(xk),0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) - XCfE1(0,0,s,0,s6) + XCfE1(xk,0,s,0,s6)))/4.;
}
double I3EM1k(double xk, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xk,-1)*(2*(mexp*n*log(xk)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) -
            log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0))) -
         2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)))*XCfE0(s,0,s6) -
      (mexp*n*log(xk) + 2*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))))*XCfE1(0,0,s,0,s6) +
      (mexp*n*log(xk) + 2*(log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0))))*XCfE1(xk,0,s,0,s6) - XCfE2(0,0,s,0,s6) +
      XCfE2(xk,0,s,0,s6)))/4.;
}
double I3E0k(double xk, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xk,-1)*((6*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(yk(xk),0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) +
            log(FB2(yk(xk),0,t(s),0,tl(s6),0)))*pow(mexp,2)*pow(n,2)*pow(log(xk),2) -
         24*mexp*n*log(xk)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) +
            pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)) -
         32*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) -
            pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
      3*(-((4*mexp*n*log(xk)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(xk),2) +
              8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE1(0,0,s,0,s6)) +
         (4*mexp*n*log(xk)*(log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(xk),2) +
            8*(pow(log(FB1(yk(xk),0,t(s),0,tl(s6),0)),2) + pow(log(FB2(yk(xk),0,t(s),0,tl(s6),0)),2)))*XCfE1(xk,0,s,0,s6) -
         2*(mexp*n*log(xk) + 2*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))))*XCfE2(0,0,s,0,s6) +
         2*(mexp*n*log(xk) + 2*(log(FB1(yk(xk),0,t(s),0,tl(s6),0)) + log(FB2(yk(xk),0,t(s),0,tl(s6),0))))*XCfE2(xk,0,s,0,s6)) -
      6*XCfE3(0,0,s,0,s6) + 6*XCfE3(xk,0,s,0,s6)))/24.;
}

double I3EM3l(double xl, double s, double s6) {
	return 0; //leading order indep
}
double I3EM2l(double xl, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xl,-1)*(2*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) +
	          log(FB2(0,yl(xl),t(s),0,tl(s6),0)))*XCfE0(s,0,s6) - XCfE1(0,0,s,0,s6) + XCfE1(0,xl,s,0,s6)))/4.;
}
double I3EM1l(double xl, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xl,-1)*(2*(mexp*n*log(xl)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) -
            log(FB2(0,0,t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0))) -
         2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) -
            pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)))*XCfE0(s,0,s6) -
      (mexp*n*log(xl) + 2*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))))*XCfE1(0,0,s,0,s6) +
      (mexp*n*log(xl) + 2*(log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0))))*XCfE1(0,xl,s,0,s6) - XCfE2(0,0,s,0,s6) +
      XCfE2(0,xl,s,0,s6)))/4.;
}
double I3E0l(double xl, double s, double s6) {
	return (pow(mexp,-1)*pow(n,-1)*pow(xl,-1)*((6*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,yl(xl),t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),0)) +
            log(FB2(0,yl(xl),t(s),0,tl(s6),0)))*pow(mexp,2)*pow(n,2)*pow(log(xl),2) -
         24*mexp*n*log(xl)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) +
            pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)) -
         32*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) -
            pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
      3*(-((4*mexp*n*log(xl)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(xl),2) +
              8*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE1(0,0,s,0,s6)) +
         (4*mexp*n*log(xl)*(log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0))) + pow(mexp,2)*pow(n,2)*pow(log(xl),2) +
            8*(pow(log(FB1(0,yl(xl),t(s),0,tl(s6),0)),2) + pow(log(FB2(0,yl(xl),t(s),0,tl(s6),0)),2)))*XCfE1(0,xl,s,0,s6) -
         2*(mexp*n*log(xl) + 2*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))))*XCfE2(0,0,s,0,s6) +
         2*(mexp*n*log(xl) + 2*(log(FB1(0,yl(xl),t(s),0,tl(s6),0)) + log(FB2(0,yl(xl),t(s),0,tl(s6),0))))*XCfE2(0,xl,s,0,s6)) -
      6*XCfE3(0,0,s,0,s6) + 6*XCfE3(0,xl,s,0,s6)))/24.;
}

double I3EM3c(double c, double s, double s6) {
	return 0; //leading order is c-indep
}
double I3EM2c(double c, double s, double s6) {
	return 2*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*
			   pow(c,-1)*pow(mexp,-2)*pow(n,-2)*XCfE0(s,0,s6);
}
double I3EM1c(double c, double s, double s6) {
	return pow(c,-1)*pow(mexp,-2)*pow(n,-2)*(4*(2*log(c)*(-log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB1(0,0,t(s),0,tl(s6),b(c))) - log(FB2(0,0,t(s),0,tl(s6),0)) +
	           log(FB2(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) +
	        pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) - pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0(s,0,s6) +
	     2*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*
	      XCfE1(0,0,s,0,s6));
}
double I3E0c(double c, double s, double s6) {
	return (pow(c,-1)*pow(mexp,-2)*pow(n,-2)*(16*(3*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) -
            log(FB2(0,0,t(s),0,tl(s6),b(c))))*pow(log(c),2) + pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) - pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),3) +
         pow(log(FB2(0,0,t(s),0,tl(s6),0)),3) + 3*log(c)*(-pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) -
            pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2)) - pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),3))*
       XCfE0(s,0,s6) - 12*(2*log(c)*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) -
            log(FB2(0,0,t(s),0,tl(s6),b(c)))) - pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB1(0,0,t(s),0,tl(s6),b(c))),2) -
         pow(log(FB2(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),b(c))),2))*XCfE1(0,0,s,0,s6) +
      6*(log(FB1(0,0,t(s),0,tl(s6),0)) - log(FB1(0,0,t(s),0,tl(s6),b(c))) + log(FB2(0,0,t(s),0,tl(s6),0)) - log(FB2(0,0,t(s),0,tl(s6),b(c))))*
       XCfE2(0,0,s,0,s6)))/3.;
}

double I3EM3s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(XCfE0(s,0,s6) - XCfE0(s,s5,s6)))/2.;
}
double I3EM2s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE0(s,0,s6) +
		       2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE0(s,s5,s6) + XCfE1(0,0,s,0,s6) -
		       XCfE1(0,0,s,s5,s6)))/2.;
}
double I3EM1s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(2*(-2*log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(log(s5),2) +
	          2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE0(s,0,s6) -
	       2*(-2*log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0))) + pow(log(s5),2) +
	          2*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)))*XCfE0(s,s5,s6) +
	       2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE1(0,0,s,0,s6) +
	       2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE1(0,0,s,s5,s6) + XCfE2(0,0,s,0,s6) -
	       XCfE2(0,0,s,s5,s6)))/2.;
}
double I3E0s(double s, double s5, double s6) {
	return (pow(mexp,-2)*pow(n,-2)*pow(s5,-1)*(-4*(-3*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*pow(log(s5),2) + pow(log(s5),3) +
	          6*log(s5)*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)) -
	          4*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),3) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),3)))*XCfE0(s,0,s6) +
	       4*(-3*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*pow(log(s5),2) + pow(log(s5),3) +
	          6*log(s5)*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)) -
	          4*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),3) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),3)))*XCfE0(s,s5,s6) +
	       3*(2*(-2*log(s5)*(log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0))) + pow(log(s5),2) +
	             2*(pow(log(FB1(0,0,t(s),0,tl(s6),0)),2) + pow(log(FB2(0,0,t(s),0,tl(s6),0)),2)))*XCfE1(0,0,s,0,s6) -
	          2*(-2*log(s5)*(log(FB1(0,0,t(s),t5(s5),tl(s6),0)) + log(FB2(0,0,t(s),t5(s5),tl(s6),0))) + pow(log(s5),2) +
	             2*(pow(log(FB1(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FB2(0,0,t(s),t5(s5),tl(s6),0)),2)))*XCfE1(0,0,s,s5,s6) +
	          2*(-log(s5) + log(FB1(0,0,t(s),0,tl(s6),0)) + log(FB2(0,0,t(s),0,tl(s6),0)))*XCfE2(0,0,s,0,s6) +
	          2*(log(s5) - log(FB1(0,0,t(s),t5(s5),tl(s6),0)) - log(FB2(0,0,t(s),t5(s5),tl(s6),0)))*XCfE2(0,0,s,s5,s6) + XCfE3(0,0,s,0,s6) -
	          XCfE3(0,0,s,s5,s6))))/6.;
}
