/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 2D integration at all eps-orders and the alpha^-1 order of the Rest-CA structure. 
 * Example: CAI2EP1AM1 ('CA' structure, 'I'ntegration over '2' dimensions, at 'E'ps to the 'Plus '1'st and 'A'lpha to the 'M'inus '1'st order) contains various logs of FXi functions 
 * evaluated at z=0,c=0,x=0,s5=0, i.e. with all the deltas from +-distributions, multiplied with the correct XCA functions to arrive at eps^1 alpha^-1. 
 */

#include <2IntCAAM1.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

using namespace std;

double CAI2EM3AM1(double w,double s6) {
	return -(pow(m,-1)*XCA00(w,s6,0,0,0))/8.;
}

double CAI2EM2AM1(double w,double s6) {
	return -(pow(m,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) + XCA01(w,s6,0,0,0)))/8.;
}

double CAI2EM1AM1(double w,double s6) {
	return -(pow(m,-1)*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) +
	        (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA01(w,s6,0,0,0) + XCA02(w,s6,0,0,0)))/8.;
}

double CAI2E0AM1(double w,double s6) {
	return -(pow(m,-1)*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA00(w,s6,0,0,0) +
	        3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA01(w,s6,0,0,0) +
	           (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA02(w,s6,0,0,0) + XCA03(w,s6,0,0,0))))/24.;
}

double CAI2EP1AM1(double w,double s6) {
	return -(pow(m,-1)*(8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),4) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),4) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),4) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),4))*XCA00(w,s6,0,0,0) +
	        8*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),3) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),3))*XCA01(w,s6,0,0,0) +
	        3*(2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA02(w,s6,0,0,0) +
	           (log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))*XCA03(w,s6,0,0,0) + XCA04(w,s6,0,0,0))))/24.;
}
