/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 4D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI4EM1sz ('CA' structure, 'I'ntegration over '4' dimensions, at 'E'ps to the 'M'inus '1'st and alpha^0 order, third and fourth integration over 's'5 and 'z') 
 * contains various differences of logs of FXi functions evaluated at c=0,x=0, i.e. with deltas from all +-distributions except the t5/s5 and u/z ones, multiplied 
 * with the correct XCA functions to arrive at eps^-1 alpha^0. 
 */

#include <4IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//third and forth integration over x, s5

double CAI4EM2xs(double w,double s6,double x,double s5) {
	return 0;
}

double CAI4EM1xs(double w,double s6,double x,double s5) {
	return (pow(s5,-1)*pow(x,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
	          log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	       (-log(FA1(v(w),tl(s6),0,t5(s5),0,0)) + log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)) - log(FA2(v(w),tl(s6),0,t5(s5),0,0)) + log(FA2(v(w),tl(s6),y(x),t5(s5),0,0)) -
	          log(FB1(v(w),tl(s6),0,t5(s5),0,0)) + log(FB1(v(w),tl(s6),y(x),t5(s5),0,0)) - log(FB2(v(w),tl(s6),0,t5(s5),0,0)) + log(FB2(v(w),tl(s6),y(x),t5(s5),0,0)))*XCA00(w,s6,s5,0,0)))/4.;
}

double CAI4E0xs(double w,double s6,double x,double s5) {
	return (pow(s5,-1)*pow(x,-1)*(-2*(log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
            log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0))) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA00(w,s6,0,0,0) +
      2*(log(s5)*(log(FA1(v(w),tl(s6),0,t5(s5),0,0)) - log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)) + log(FA2(v(w),tl(s6),0,t5(s5),0,0)) - log(FA2(v(w),tl(s6),y(x),t5(s5),0,0)) +
            log(FB1(v(w),tl(s6),0,t5(s5),0,0)) - log(FB1(v(w),tl(s6),y(x),t5(s5),0,0)) + log(FB2(v(w),tl(s6),0,t5(s5),0,0)) - log(FB2(v(w),tl(s6),y(x),t5(s5),0,0))) -
         pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FA1(v(w),tl(s6),y(x),t5(s5),0,0)),2) - pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2) +
         pow(log(FA2(v(w),tl(s6),y(x),t5(s5),0,0)),2) - pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB1(v(w),tl(s6),y(x),t5(s5),0,0)),2) -
         pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2) + pow(log(FB2(v(w),tl(s6),y(x),t5(s5),0,0)),2))*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
      log(FA1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FA2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) +
      log(FB1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
      log(FB2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA01(w,s6,s5,0,0) -
      log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) + log(FA2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA01(w,s6,s5,0,0) - log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) +
      log(FB1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA01(w,s6,s5,0,0) - log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA01(w,s6,s5,0,0)))/4.;
}

//third and forth integration over x, z

double CAI4EM2xz(double w,double s6,double x,double z) {
	return 0;
}

double CAI4EM1xz(double w,double s6,double x,double z) {
	return (pow(x,-1)*pow(z,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
	          log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	       (-log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA1(v(w),tl(s6),y(x),0,u(z),0)) - log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),y(x),0,u(z),0)) - log(FB1(v(w),tl(s6),0,0,u(z),0)) +
	          log(FB1(v(w),tl(s6),y(x),0,u(z),0)) - log(FB2(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),y(x),0,u(z),0)))*XCA00(w,s6,0,z,0)))/2.;
}

double CAI4E0xz(double w,double s6,double x,double z) {
	return (pow(x,-1)*pow(z,-1)*(-2*(2*log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
            log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0))) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA00(w,s6,0,0,0) +
      2*(2*log(z)*(log(FA1(v(w),tl(s6),0,0,u(z),0)) - log(FA1(v(w),tl(s6),y(x),0,u(z),0)) + log(FA2(v(w),tl(s6),0,0,u(z),0)) - log(FA2(v(w),tl(s6),y(x),0,u(z),0)) +
            log(FB1(v(w),tl(s6),0,0,u(z),0)) - log(FB1(v(w),tl(s6),y(x),0,u(z),0)) + log(FB2(v(w),tl(s6),0,0,u(z),0)) - log(FB2(v(w),tl(s6),y(x),0,u(z),0))) -
         pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA1(v(w),tl(s6),y(x),0,u(z),0)),2) - pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,u(z),0)),2) -
         pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),y(x),0,u(z),0)),2) - pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB2(v(w),tl(s6),y(x),0,u(z),0)),2))*
       XCA00(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
      log(FA2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FB1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) +
      log(FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) +
      log(FA1(v(w),tl(s6),y(x),0,u(z),0))*XCA01(w,s6,0,z,0) - log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) + log(FA2(v(w),tl(s6),y(x),0,u(z),0))*XCA01(w,s6,0,z,0) -
      log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) + log(FB1(v(w),tl(s6),y(x),0,u(z),0))*XCA01(w,s6,0,z,0) - log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) +
      log(FB2(v(w),tl(s6),y(x),0,u(z),0))*XCA01(w,s6,0,z,0)))/2.;
}


//third and forth integration over x, c

double CAI4EM2xc(double w,double s6,double x,double c) {
	return 0;
}

double CAI4EM1xc(double w,double s6,double x,double c) {
	return (pow(c,-1)*pow(x,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) -
	          log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	       (-log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA1(v(w),tl(s6),y(x),0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),y(x),0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	          log(FB1(v(w),tl(s6),y(x),0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XCA00(w,s6,0,0,c)))/2.;
}

double CAI4E0xc(double w,double s6,double x,double c) {
	return (pow(c,-1)*pow(x,-1)*(-2*(2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
            log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0))) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FA1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) +
         pow(log(FB1(v(w),tl(s6),y(x),0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),y(x),0,0,0)),2))*XCA00(w,s6,0,0,0) +
      2*(2*log(c)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA1(v(w),tl(s6),y(x),0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),y(x),0,0,b(c))) +
            log(FB1(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),y(x),0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))) - log(FB2(v(w),tl(s6),y(x),0,0,b(c)))) -
         pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA1(v(w),tl(s6),y(x),0,0,b(c))),2) - pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),y(x),0,0,b(c))),2) -
         pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),y(x),0,0,b(c))),2) - pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),y(x),0,0,b(c))),2))*
       XCA00(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FA2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
      log(FA2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) + log(FB1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB1(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) +
      log(FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB2(v(w),tl(s6),y(x),0,0,0))*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) +
      log(FA1(v(w),tl(s6),y(x),0,0,b(c)))*XCA01(w,s6,0,0,c) - log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FA2(v(w),tl(s6),y(x),0,0,b(c)))*XCA01(w,s6,0,0,c) -
      log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FB1(v(w),tl(s6),y(x),0,0,b(c)))*XCA01(w,s6,0,0,c) - log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) +
      log(FB2(v(w),tl(s6),y(x),0,0,b(c)))*XCA01(w,s6,0,0,c)))/2.;
}


//third and forth integration over s5, z

double CAI4EM2sz(double w,double s6,double s5,double z) {
	return (pow(m,-1)*pow(s5,-1)*pow(z,-1)*(XCA00(w,s6,0,0,0) - XCA00(w,s6,0,z,0) - XCA00(w,s6,s5,0,0) + XCA00(w,s6,s5,z,0)))/2.;
}

double CAI4EM1sz(double w,double s6,double s5,double z) {
	return (pow(m,-1)*pow(s5,-1)*pow(z,-1)*(-2*(log(s5) + 2*log(z))*XCA00(w,s6,0,0,0) + 2*(log(s5) + 2*log(z))*XCA00(w,s6,0,z,0) + 2*log(s5)*XCA00(w,s6,s5,0,0) + 4*log(z)*XCA00(w,s6,s5,0,0) -
		       2*log(s5)*XCA00(w,s6,s5,z,0) - 4*log(z)*XCA00(w,s6,s5,z,0) + XCA01(w,s6,0,0,0) - XCA01(w,s6,0,z,0) - XCA01(w,s6,s5,0,0) + XCA01(w,s6,s5,z,0) - 2*XCA10(w,s6,0,0,0) +
		       2*XCA10(w,s6,0,z,0) + 2*XCA10(w,s6,s5,0,0) - 2*XCA10(w,s6,s5,z,0)))/2.;
}

double CAI4E0sz(double w,double s6,double s5,double z) {
	return (pow(m,-1)*pow(s5,-1)*pow(z,-1)*(2*(4*log(s5)*log(z) + pow(log(s5),2) + 4*pow(log(z),2) - pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) -
	          pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) - pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) +
	       2*(-4*log(s5)*log(z) - pow(log(s5),2) - 4*pow(log(z),2) + pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2) + pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2) +
	          pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2))*XCA00(w,s6,0,z,0) - 8*log(s5)*log(z)*XCA00(w,s6,s5,0,0) - 2*pow(log(s5),2)*XCA00(w,s6,s5,0,0) - 8*pow(log(z),2)*XCA00(w,s6,s5,0,0) +
	       2*pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) + 2*pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) +
	       2*pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) + 2*pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) + 8*log(s5)*log(z)*XCA00(w,s6,s5,z,0) +
	       2*pow(log(s5),2)*XCA00(w,s6,s5,z,0) + 8*pow(log(z),2)*XCA00(w,s6,s5,z,0) - 2*pow(log(FA1(v(w),tl(s6),0,t5(s5),u(z),0)),2)*XCA00(w,s6,s5,z,0) -
	       2*pow(log(FA2(v(w),tl(s6),0,t5(s5),u(z),0)),2)*XCA00(w,s6,s5,z,0) - 2*pow(log(FB1(v(w),tl(s6),0,t5(s5),u(z),0)),2)*XCA00(w,s6,s5,z,0) -
	       2*pow(log(FB2(v(w),tl(s6),0,t5(s5),u(z),0)),2)*XCA00(w,s6,s5,z,0) - 2*log(s5)*XCA01(w,s6,0,0,0) - 4*log(z)*XCA01(w,s6,0,0,0) + 2*log(s5)*XCA01(w,s6,0,z,0) +
	       4*log(z)*XCA01(w,s6,0,z,0) + 2*log(s5)*XCA01(w,s6,s5,0,0) + 4*log(z)*XCA01(w,s6,s5,0,0) - 2*log(s5)*XCA01(w,s6,s5,z,0) - 4*log(z)*XCA01(w,s6,s5,z,0) + XCA02(w,s6,0,0,0) -
	       XCA02(w,s6,0,z,0) - XCA02(w,s6,s5,0,0) + XCA02(w,s6,s5,z,0) + 4*log(s5)*XCA10(w,s6,0,0,0) + 8*log(z)*XCA10(w,s6,0,0,0) - 2*log(FA1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) -
	       2*log(FA2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FB1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FB2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) -
	       4*log(s5)*XCA10(w,s6,0,z,0) - 8*log(z)*XCA10(w,s6,0,z,0) + 2*log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) + 2*log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) +
	       2*log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) + 2*log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) - 4*log(s5)*XCA10(w,s6,s5,0,0) - 8*log(z)*XCA10(w,s6,s5,0,0) +
	       2*log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 2*log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 2*log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) +
	       2*log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 4*log(s5)*XCA10(w,s6,s5,z,0) + 8*log(z)*XCA10(w,s6,s5,z,0) - 2*log(FA1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA10(w,s6,s5,z,0) -
	       2*log(FA2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA10(w,s6,s5,z,0) - 2*log(FB1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA10(w,s6,s5,z,0) - 2*log(FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA10(w,s6,s5,z,0) -
	       2*XCA11(w,s6,0,0,0) + 2*XCA11(w,s6,0,z,0) + 2*XCA11(w,s6,s5,0,0) - 2*XCA11(w,s6,s5,z,0)))/2.;
}


//third and forth integration over s5, c

double CAI4EM2sc(double w,double s6,double s5,double c) {
	return 0;
}

double CAI4EM1sc(double w,double s6,double s5,double c) {
	return (pow(c,-1)*pow(m,-1)*pow(s5,-1)*((4*log(c) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*
	        XCA00(w,s6,0,0,0) + (-4*log(c) + log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*
	        XCA00(w,s6,0,0,c) - 4*log(c)*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) +
	       log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + 4*log(c)*XCA00(w,s6,s5,0,c) -
	       log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) -
	       log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - 2*XCA10(w,s6,0,0,0) + 2*XCA10(w,s6,0,0,c) + 2*XCA10(w,s6,s5,0,0) - 2*XCA10(w,s6,s5,0,c)))/2.;
}

double CAI4E0sc(double w,double s6,double s5,double c) {
	return (pow(c,-1)*pow(m,-1)*pow(s5,-1)*(2*(log(s5)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) +
	          4*log(c)*(-log(s5) + log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0))) - 8*pow(log(c),2) -
	          2*(pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2)))*XCA00(w,s6,0,0,0) +
	       2*(4*log(c)*(log(s5) - log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c)))) -
	          log(s5)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c)))) + 8*pow(log(c),2) +
	          2*(pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2)))*
	        XCA00(w,s6,0,0,c) + 8*log(c)*log(s5)*XCA00(w,s6,s5,0,0) - 8*log(c)*log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) - 8*log(c)*log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	       2*log(s5)*log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) - 8*log(c)*log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	       2*log(s5)*log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) - 8*log(c)*log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	       2*log(s5)*log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + 16*pow(log(c),2)*XCA00(w,s6,s5,0,0) + 4*pow(log(FA1(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) +
	       4*pow(log(FA2(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) + 4*pow(log(FB1(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) +
	       4*pow(log(FB2(v(w),tl(s6),0,t5(s5),0,0)),2)*XCA00(w,s6,s5,0,0) - 8*log(c)*log(s5)*XCA00(w,s6,s5,0,c) + 8*log(c)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) +
	       2*log(s5)*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + 8*log(c)*log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) +
	       2*log(s5)*log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + 8*log(c)*log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) +
	       2*log(s5)*log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + 8*log(c)*log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) +
	       2*log(s5)*log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - 16*pow(log(c),2)*XCA00(w,s6,s5,0,c) - 4*pow(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))),2)*XCA00(w,s6,s5,0,c) -
	       4*pow(log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))),2)*XCA00(w,s6,s5,0,c) - 4*pow(log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))),2)*XCA00(w,s6,s5,0,c) -
	       4*pow(log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))),2)*XCA00(w,s6,s5,0,c) + 4*log(c)*XCA01(w,s6,0,0,0) - log(FA1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
	       log(FA2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - 4*log(c)*XCA01(w,s6,0,0,c) +
	       log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) +
	       log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) - 4*log(c)*XCA01(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) +
	       log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) + log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA01(w,s6,s5,0,0) +
	       4*log(c)*XCA01(w,s6,s5,0,c) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA01(w,s6,s5,0,c) - log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA01(w,s6,s5,0,c) -
	       log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA01(w,s6,s5,0,c) - log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA01(w,s6,s5,0,c) + 8*log(c)*XCA10(w,s6,0,0,0) + 4*log(s5)*XCA10(w,s6,0,0,0) -
	       2*log(FA1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FA2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FB1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) -
	       2*log(FB2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 8*log(c)*XCA10(w,s6,0,0,c) - 4*log(s5)*XCA10(w,s6,0,0,c) + 2*log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) +
	       2*log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) + 2*log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) + 2*log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) -
	       8*log(c)*XCA10(w,s6,s5,0,0) - 4*log(s5)*XCA10(w,s6,s5,0,0) + 2*log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 2*log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) +
	       2*log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 2*log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA10(w,s6,s5,0,0) + 8*log(c)*XCA10(w,s6,s5,0,c) + 4*log(s5)*XCA10(w,s6,s5,0,c) -
	       2*log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA10(w,s6,s5,0,c) - 2*log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA10(w,s6,s5,0,c) - 2*log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA10(w,s6,s5,0,c) -
	       2*log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA10(w,s6,s5,0,c) - 2*XCA11(w,s6,0,0,0) + 2*XCA11(w,s6,0,0,c) + 2*XCA11(w,s6,s5,0,0) - 2*XCA11(w,s6,s5,0,c)))/2.;
}


//third and forth integration over z, c

double CAI4EM2zc(double w,double s6,double z,double c) {
	return 0;
}

double CAI4EM1zc(double w,double s6,double z,double c) {
	return pow(c,-1)*pow(m,-1)*pow(z,-1)*((4*log(c) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*XCA00(w,s6,0,0,0) +
		     (-4*log(c) + log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*XCA00(w,s6,0,0,c) -
		     4*log(c)*XCA00(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) +
		     log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + 4*log(c)*XCA00(w,s6,0,z,c) -
		     log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) -
		     log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - 2*XCA10(w,s6,0,0,0) + 2*XCA10(w,s6,0,0,c) + 2*XCA10(w,s6,0,z,0) - 2*XCA10(w,s6,0,z,c));
}

double CAI4E0zc(double w,double s6,double z,double c) {
	return pow(c,-1)*pow(m,-1)*pow(z,-1)*(-4*(-(log(z)*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))) +
	        log(c)*(4*log(z) - 2*(log(FA1(v(w),tl(s6),0,0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) + log(FB1(v(w),tl(s6),0,0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)))) + 4*pow(log(c),2) +
	        pow(log(FA1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FA2(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB1(v(w),tl(s6),0,0,0,0)),2) + pow(log(FB2(v(w),tl(s6),0,0,0,0)),2))*XCA00(w,s6,0,0,0) +
	     4*(-(log(z)*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))) +
	        log(c)*(4*log(z) - 2*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))) + 4*pow(log(c),2) +
	        pow(log(FA1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FA2(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB1(v(w),tl(s6),0,0,0,b(c))),2) + pow(log(FB2(v(w),tl(s6),0,0,0,b(c))),2))*
	      XCA00(w,s6,0,0,c) + 16*log(c)*log(z)*XCA00(w,s6,0,z,0) - 8*log(c)*log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) - 4*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) -
	     8*log(c)*log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) - 4*log(z)*log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) - 8*log(c)*log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) -
	     4*log(z)*log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) - 8*log(c)*log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) - 4*log(z)*log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) +
	     16*pow(log(c),2)*XCA00(w,s6,0,z,0) + 4*pow(log(FA1(v(w),tl(s6),0,0,u(z),0)),2)*XCA00(w,s6,0,z,0) + 4*pow(log(FA2(v(w),tl(s6),0,0,u(z),0)),2)*XCA00(w,s6,0,z,0) +
	     4*pow(log(FB1(v(w),tl(s6),0,0,u(z),0)),2)*XCA00(w,s6,0,z,0) + 4*pow(log(FB2(v(w),tl(s6),0,0,u(z),0)),2)*XCA00(w,s6,0,z,0) - 16*log(c)*log(z)*XCA00(w,s6,0,z,c) +
	     8*log(c)*log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) + 4*log(z)*log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) +
	     8*log(c)*log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) + 4*log(z)*log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) +
	     8*log(c)*log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) + 4*log(z)*log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) +
	     8*log(c)*log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) + 4*log(z)*log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - 16*pow(log(c),2)*XCA00(w,s6,0,z,c) -
	     4*pow(log(FA1(v(w),tl(s6),0,0,u(z),b(c))),2)*XCA00(w,s6,0,z,c) - 4*pow(log(FA2(v(w),tl(s6),0,0,u(z),b(c))),2)*XCA00(w,s6,0,z,c) -
	     4*pow(log(FB1(v(w),tl(s6),0,0,u(z),b(c))),2)*XCA00(w,s6,0,z,c) - 4*pow(log(FB2(v(w),tl(s6),0,0,u(z),b(c))),2)*XCA00(w,s6,0,z,c) + 4*log(c)*XCA01(w,s6,0,0,0) -
	     log(FA1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FA2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - log(FB1(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) -
	     log(FB2(v(w),tl(s6),0,0,0,0))*XCA01(w,s6,0,0,0) - 4*log(c)*XCA01(w,s6,0,0,c) + log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) +
	     log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) + log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA01(w,s6,0,0,c) - 4*log(c)*XCA01(w,s6,0,z,0) +
	     log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) + log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) + log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) +
	     log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA01(w,s6,0,z,0) + 4*log(c)*XCA01(w,s6,0,z,c) - log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA01(w,s6,0,z,c) -
	     log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA01(w,s6,0,z,c) - log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA01(w,s6,0,z,c) - log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA01(w,s6,0,z,c) +
	     8*log(c)*XCA10(w,s6,0,0,0) + 8*log(z)*XCA10(w,s6,0,0,0) - 2*log(FA1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FA2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) -
	     2*log(FB1(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 2*log(FB2(v(w),tl(s6),0,0,0,0))*XCA10(w,s6,0,0,0) - 8*log(c)*XCA10(w,s6,0,0,c) - 8*log(z)*XCA10(w,s6,0,0,c) +
	     2*log(FA1(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) + 2*log(FA2(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) + 2*log(FB1(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) +
	     2*log(FB2(v(w),tl(s6),0,0,0,b(c)))*XCA10(w,s6,0,0,c) - 8*log(c)*XCA10(w,s6,0,z,0) - 8*log(z)*XCA10(w,s6,0,z,0) + 2*log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) +
	     2*log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) + 2*log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) + 2*log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA10(w,s6,0,z,0) +
	     8*log(c)*XCA10(w,s6,0,z,c) + 8*log(z)*XCA10(w,s6,0,z,c) - 2*log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA10(w,s6,0,z,c) - 2*log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA10(w,s6,0,z,c) -
	     2*log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA10(w,s6,0,z,c) - 2*log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA10(w,s6,0,z,c) - 2*XCA11(w,s6,0,0,0) + 2*XCA11(w,s6,0,0,c) + 2*XCA11(w,s6,0,z,0) -
	     2*XCA11(w,s6,0,z,c));
}
