/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCAij for the 5D integration at all eps-orders and the alpha^0 order of the Rest-CA structure. 
 * Example: CAI5EM1x ('CA' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the 'M'inus '1'st and alpha^0 order, with the only missing integration over 'x') 
 * contains various differences of logs of FXi functions evaluated at x=0, i.e. with only the delta arising from the y/x +-distribution, multiplied 
 * with the correct XCA functions to arrive at eps^-1 alpha^0. 
 */

#include <5IntCA.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorCA.h>
#include <Input_Common.h>

//missing integration x

double CAI5E0x(double w,double s6,double z,double s5,double c) {
	return 2*pow(c,-1)*pow(m,-1)*pow(s5,-1)*pow(z,-1)*((4*log(c) - log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),0,0,0,0)))*
		      XCA00(w,s6,0,0,0) + (-4*log(c) + log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*
		      XCA00(w,s6,0,0,c) - 4*log(c)*XCA00(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) +
		     log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + 4*log(c)*XCA00(w,s6,0,z,c) -
		     log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) -
		     log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - 4*log(c)*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) +
		     log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) +
		     4*log(c)*XCA00(w,s6,s5,0,c) - log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) -
		     log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + 4*log(c)*XCA00(w,s6,s5,z,0) -
		     log(FA1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - log(FA2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - log(FB1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) -
		     log(FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - 4*log(c)*XCA00(w,s6,s5,z,c) + log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA00(w,s6,s5,z,c) +
		     log(FA2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA00(w,s6,s5,z,c) + log(FB1(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA00(w,s6,s5,z,c) + log(FB2(v(w),tl(s6),0,t5(s5),u(z),b(c)))*XCA00(w,s6,s5,z,c) -
		     2*XCA10(w,s6,0,0,0) + 2*XCA10(w,s6,0,0,c) + 2*XCA10(w,s6,0,z,0) - 2*XCA10(w,s6,0,z,c) + 2*XCA10(w,s6,s5,0,0) - 2*XCA10(w,s6,s5,0,c) - 2*XCA10(w,s6,s5,z,0) + 2*XCA10(w,s6,s5,z,c));
}

//missing integration s5

double CAI5E0s(double w,double s6,double x,double z,double c) {
	return 2*pow(c,-1)*pow(x,-1)*pow(z,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
	        log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	     (-log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA1(v(w),tl(s6),y(x),0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),y(x),0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	        log(FB1(v(w),tl(s6),y(x),0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XCA00(w,s6,0,0,c) - log(FA1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) +
	     log(FA1(v(w),tl(s6),y(x),0,u(z),0))*XCA00(w,s6,0,z,0) - log(FA2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FA2(v(w),tl(s6),y(x),0,u(z),0))*XCA00(w,s6,0,z,0) -
	     log(FB1(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) + log(FB1(v(w),tl(s6),y(x),0,u(z),0))*XCA00(w,s6,0,z,0) - log(FB2(v(w),tl(s6),0,0,u(z),0))*XCA00(w,s6,0,z,0) +
	     log(FB2(v(w),tl(s6),y(x),0,u(z),0))*XCA00(w,s6,0,z,0) + log(FA1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FA1(v(w),tl(s6),y(x),0,u(z),b(c)))*XCA00(w,s6,0,z,c) +
	     log(FA2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FA2(v(w),tl(s6),y(x),0,u(z),b(c)))*XCA00(w,s6,0,z,c) + log(FB1(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) -
	     log(FB1(v(w),tl(s6),y(x),0,u(z),b(c)))*XCA00(w,s6,0,z,c) + log(FB2(v(w),tl(s6),0,0,u(z),b(c)))*XCA00(w,s6,0,z,c) - log(FB2(v(w),tl(s6),y(x),0,u(z),b(c)))*XCA00(w,s6,0,z,c));
}

//missing integration z

double CAI5E0z(double w,double s6,double x,double s5,double c) {
	return pow(c,-1)*pow(s5,-1)*pow(x,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
	        log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	     (-log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA1(v(w),tl(s6),y(x),0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),y(x),0,0,b(c))) - log(FB1(v(w),tl(s6),0,0,0,b(c))) +
	        log(FB1(v(w),tl(s6),y(x),0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XCA00(w,s6,0,0,c) -
	     log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) - log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) +
	     log(FA2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) - log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	     log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) -
	     log(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) +
	     log(FB1(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) - log(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) + log(FB2(v(w),tl(s6),0,t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c) -
	     log(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c)))*XCA00(w,s6,s5,0,c));
}

//missing integration c

double CAI5E0c(double w,double s6,double x,double z,double s5) {
	return pow(s5,-1)*pow(x,-1)*pow(z,-1)*((log(FA1(v(w),tl(s6),0,0,0,0)) - log(FA1(v(w),tl(s6),y(x),0,0,0)) + log(FA2(v(w),tl(s6),0,0,0,0)) - log(FA2(v(w),tl(s6),y(x),0,0,0)) +
	        log(FB1(v(w),tl(s6),0,0,0,0)) - log(FB1(v(w),tl(s6),y(x),0,0,0)) + log(FB2(v(w),tl(s6),0,0,0,0)) - log(FB2(v(w),tl(s6),y(x),0,0,0)))*XCA00(w,s6,0,0,0) +
	     (-log(FA1(v(w),tl(s6),0,0,u(z),0)) + log(FA1(v(w),tl(s6),y(x),0,u(z),0)) - log(FA2(v(w),tl(s6),0,0,u(z),0)) + log(FA2(v(w),tl(s6),y(x),0,u(z),0)) - log(FB1(v(w),tl(s6),0,0,u(z),0)) +
	        log(FB1(v(w),tl(s6),y(x),0,u(z),0)) - log(FB2(v(w),tl(s6),0,0,u(z),0)) + log(FB2(v(w),tl(s6),y(x),0,u(z),0)))*XCA00(w,s6,0,z,0) -
	     log(FA1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) - log(FA2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) +
	     log(FA2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) - log(FB1(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB1(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) -
	     log(FB2(v(w),tl(s6),0,t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FB2(v(w),tl(s6),y(x),t5(s5),0,0))*XCA00(w,s6,s5,0,0) + log(FA1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) -
	     log(FA1(v(w),tl(s6),y(x),t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) + log(FA2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - log(FA2(v(w),tl(s6),y(x),t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) +
	     log(FB1(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) - log(FB1(v(w),tl(s6),y(x),t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) + log(FB2(v(w),tl(s6),0,t5(s5),u(z),0))*XCA00(w,s6,s5,z,0) -
	     log(FB2(v(w),tl(s6),y(x),t5(s5),u(z),0))*XCA00(w,s6,s5,z,0));
}
