/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XNfij for the 5D integration at all eps-orders and the alpha^0 order of the nf structure. 
 * Example: NfI5E0x ('Nf' structure, 'I'ntegration over '5' dimensions, at 'E'ps to the '0'th and alpha^0 order, only missing integration over 'x') 
 * contains logs of FXi functions evaluated at x=0, i.e. with only the delta from the y/x +-distribution, multiplied 
 * with the correct XNf functions to arrive at eps^0 alpha^0. 
 */

#include <5IntNF.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactorNf.h>
#include <Input_Common.h>

/*
 * leading terms (1/eps) vanish, since that means integrating x
 * (otherwise there'd be an alpha), which has a vanishing
 * leading order in its +-dist
 */

// additional integrations run over x, s5

double NfI5E0z(double w,double s6,double x,double s5,double c) {
	return pow(s5,-1)*pow(x,-1)*((-log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA1(v(w),tl(s6),y(x),0,0,b(c))) - log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),y(x),0,0,b(c))) -
	        log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),y(x),0,0,b(c))) - log(FB2(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XNf00(w,s6,0,0,c) +
	     (log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FA1(v(w),tl(s6),y(x),t5(s5),0,b(c))) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FA2(v(w),tl(s6),y(x),t5(s5),0,b(c))) +
	        log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FB1(v(w),tl(s6),y(x),t5(s5),0,b(c))) + log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))) - log(FB2(v(w),tl(s6),y(x),t5(s5),0,b(c))))*XNf00(w,s6,s5,0,c)
	     );
}

// additional integrations run over x, z

double NfI5E0s(double w,double s6,double x,double z,double c) {
	return -2*pow(x,-1)*pow(z,-1)*((log(FA1(v(w),tl(s6),0,0,0,b(c))) - log(FA1(v(w),tl(s6),y(x),0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) - log(FA2(v(w),tl(s6),y(x),0,0,b(c))) +
	        log(FB1(v(w),tl(s6),0,0,0,b(c))) - log(FB1(v(w),tl(s6),y(x),0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))) - log(FB2(v(w),tl(s6),y(x),0,0,b(c))))*XNf00(w,s6,0,0,c) +
	     (-log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA1(v(w),tl(s6),y(x),0,u(z),b(c))) - log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),y(x),0,u(z),b(c))) -
	        log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),y(x),0,u(z),b(c))) - log(FB2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),y(x),0,u(z),b(c))))*XNf00(w,s6,0,z,c));
}

// additional integrations run over s5, z

double NfI5E0x(double w,double s6,double s5,double z,double c) {
	return pow(m,-1)*pow(s5,-1)*pow(z,-1)*(2*(log(FA1(v(w),tl(s6),0,0,0,b(c))) + log(FA2(v(w),tl(s6),0,0,0,b(c))) + log(FB1(v(w),tl(s6),0,0,0,b(c))) + log(FB2(v(w),tl(s6),0,0,0,b(c))))*
		      XNf00(w,s6,0,0,c) - 2*(log(FA1(v(w),tl(s6),0,0,u(z),b(c))) + log(FA2(v(w),tl(s6),0,0,u(z),b(c))) + log(FB1(v(w),tl(s6),0,0,u(z),b(c))) + log(FB2(v(w),tl(s6),0,0,u(z),b(c))))*
		      XNf00(w,s6,0,z,c) - 2*(log(FA1(v(w),tl(s6),0,t5(s5),0,b(c))) + log(FA2(v(w),tl(s6),0,t5(s5),0,b(c))) + log(FB1(v(w),tl(s6),0,t5(s5),0,b(c))) + log(FB2(v(w),tl(s6),0,t5(s5),0,b(c))))*
		      XNf00(w,s6,s5,0,c) + 2*(log(FA1(v(w),tl(s6),0,t5(s5),u(z),b(c))) + log(FA2(v(w),tl(s6),0,t5(s5),u(z),b(c))) + log(FB1(v(w),tl(s6),0,t5(s5),u(z),b(c))) +
		        log(FB2(v(w),tl(s6),0,t5(s5),u(z),b(c))))*XNf00(w,s6,s5,z,c) + 4*XNf10(w,s6,0,0,c) - 4*XNf10(w,s6,0,z,c) - 4*XNf10(w,s6,s5,0,c) + 4*XNf10(w,s6,s5,z,c));
}
