//undocumented special feature, please ignore this file

#include <Auxiliaries.h>
#include <cuba.h>
#include <IntAD.h>
#include <Input_Common.h>

#include <cmath>
#include <iostream>
#include <fstream>
#include <string>

#include <stdlib.h>
#include <sys/types.h>
#include <algorithm>
#include <cstdlib>
#include <string.h>
#include <unistd.h>
#include <stdio.h>
#include <sys/ipc.h>
#include <sys/shm.h>
#include <sys/wait.h>

using namespace std;


	// contains the results of the numerical integration for CA, nf and Cf
	double resAD[]={0,0,0,0};

	// contains the error estimates according to the scheme outlined above
	double errAD[]={0,0,0,0};

	// contains the probabilities that the error estimate is incorrect
	double probAD[]={0,0,0,0};

	//variable containing the number of regions into which the integrator splits the integrand, irrelevant for us
	int nregions=0;

	/* The following variables are only necessary because of a specific problem: The Cuba integrators print their logs
	 * on stdout using puts() and fflush(). I want them to write to a file, but as I don't want to modify the Cuba
	 * sources, I have to work around that. There is a possibility of rerouting stdout to a file using freopen,
	 * but this is irreversible. Once stdout is rerouted, I can't send it back to the console. Solution: let Cuba
	 * run inside a child process that receives a copy of all file descriptors of the parent at its fork. If I
	 * freopen stdout in the child, let it terminate and then continue in the parent, the parent's stdout is still
	 * unaffected. Problem with that:
	 * Child and parent have different memory address spaces, each gets a copy of all variables and works only with
	 * those. So we need to introduce shared memory for the variables that the child modifies and the parent needs to
	 * read, i.e. the result, error estimate and error probability. */

	//process ids for the various child processes
	pid_t child;

	/*
	 * Shm always denotes something shared
	 */

	//memory ids for shared memory between parent and child
	int ShmResId,ShmErrId,ShmProbId,ShmNevId,ShmTerId;
	//pointers to shared memory for results, error estimates and error probabilities (these are arrays of type double)
	double *ShmRes, *ShmErr, *ShmProb;
	//pointer to shared process variable neval (# function evaluations), determined by child, but required by parent
	long long int *ShmNev;
	//pointer to shared process variable terminate, which is determined by child, but required by parent
	int *ShmTer;

	//file stream for output
	ofstream output;
	string outputname;

	 /*     ____             _
	  *    | __ )  ___  __ _(_)_ __    _ __  _ __ ___   __ _ _ __ __ _ _ __ ___
	  *    |  _ \ / _ \/ _` | | '_ \  | '_ \| '__/ _ \ / _` | '__/ _` | '_ ` _ \
	  *    | |_) |  __/ (_| | | | | | | |_) | | | (_) | (_| | | | (_| | | | | | |
	  *    |____/ \___|\__, |_|_| |_| | .__/|_|  \___/ \__, |_|  \__,_|_| |_| |_|
	  *                |___/          |_|              |___/
	  */

int main() {
	//open output file
	outputname="Result "+observable+" AD Mom.txt";
	output.open(outputname.c_str());

	//Info header
	cout << "Observable name: " << observable << "." << endl;
	cout << "Starting calculation for AD Mom results." << endl;

	/* Request shared memory for result ("Res", double type array of length ncompAD),
	 * error estimate ("Err", double array of length ncompAD),
	 * probability of wrong error ("Prob", double type array of length ncompAD),
	 * neval variable ("Nev", long long int),
	 * termination code ("Ter", int);
	 *
	 * shmget returns the Id of the memory block (int type) if successful, -1 if it fails */
	ShmResId=shmget(IPC_PRIVATE, ncompAD*sizeof(double), 0777|IPC_CREAT);
	ShmErrId=shmget(IPC_PRIVATE, ncompAD*sizeof(double), 0777|IPC_CREAT);
	ShmProbId=shmget(IPC_PRIVATE, ncompAD*sizeof(double), 0777|IPC_CREAT);
	ShmNevId=shmget(IPC_PRIVATE, sizeof(long long int), 0777|IPC_CREAT);
	ShmTerId=shmget(IPC_PRIVATE, sizeof(int), 0777|IPC_CREAT);

	//check if shared memory request was successful
	if(ShmResId<0 || ShmErrId <0 || ShmProbId<0 || ShmNevId<0 || ShmTerId<0) {
		cout << "Shared memory request failed." << endl;
		exit(EXIT_FAILURE);
	}

	/* Attach memory to parent's address space
	 *
	 * This construction is necessary, as shmat returns a pointer of type void*, which should be typecast
	 * to whatever we need (double* for ShmRes, ShmErr, ShmProb; long long int* for ShmNev; and int* for ShmTer).
	 * However, if shmat fails, it returns a char* -1, so to check I assign this return value to a void* pointer
	 * called Attx, check if it evaluates to -1 if typecast as char*, and if it doesn't (i.e. if the attachment
	 * was successful), I typecast Attx to double*, long long int*, or int*, and assign it to ShmRes, etc.	*/
	void *Att1,*Att2,*Att3,*Att4,*Att5;
	Att1 = shmat(ShmResId, NULL, 0);
	Att2 = shmat(ShmErrId, NULL, 0);
	Att3 = shmat(ShmProbId, NULL, 0);
	Att4 = shmat(ShmNevId, NULL, 0);
	Att5 = shmat(ShmTerId, NULL, 0);
	if((char*)Att1==(char*)-1 || (char*)Att2==(char*)-1 || (char*)Att3==(char*)-1 || (char*)Att4==(char*)-1 || (char*)Att5==(char*)-1) {
		cout << "Shared memory attachment failed" << endl;
		exit(EXIT_FAILURE);
	} else {
		ShmRes = (double*) Att1;
		ShmErr = (double*) Att2;
		ShmProb = (double*) Att3;
		ShmNev = (long long int*) Att4;
		ShmTer = (int*) Att5;
	}

	//start integration
	cout << "Numerical integration in progress..." << endl;

	//create child process and check if this was successful
	child=fork();
	if(child <0) { ///
		cout << "Fork for numerical integration failed" << endl;
		exit(EXIT_FAILURE);
	} //everything in here is the child process
	else if(child==0) {

		//reset shared memory to zeros...
		for(int i=0; i<ncompAD; i++) {
				*(ShmRes+i)=0;
				*(ShmErr+i)=0;
				*(ShmProb+i)=0;
			}

		//choose the integrand from the auxiliary sources
		integrand_t Integ= &ADMom;

		//reroute output of llDivonne to a text file
		if(freopen("AnomDim.log","w",stdout)==NULL) {
			cout << "Redirecting output stream failed" << endl;
			exit(EXIT_FAILURE);
		}

		//perform the integration
		llDivonne(ndimAD, ncompAD, Integ,0, 1, epsrel4, epsabs4, flags, seed, 0, maxeval4, key14, key24, key34, maxpass4, border, maxchisq, mindev, 0, ndimAD, 0, 0, 0, "", 0, &nregions, ShmNev, ShmTer, ShmRes, ShmErr, ShmProb);

		//terminate the child
		_exit(EXIT_SUCCESS);
	}

	/* Parent process
	 *
	 * Strictly, this is shared code between child and parent, but the child is terminated before this point */

	//wait until child has terminated
	wait(NULL);

	//transfer results from shared memory to parent
	copy(ShmRes,(ShmRes+ncompAD),resAD);
	copy(ShmErr,(ShmErr+ncompAD),errAD);
	copy(ShmProb,(ShmProb+ncompAD),probAD);

	//first integration finished
	if(*ShmTer<0) {
			cout << "Dimension of integration out of range, please contact developer, this should never happen." << endl;
		} else if(*ShmTer>0) {
			cout << " Numerical integration stopped, accuracy not reached. Continuing with intermediate results." << endl;
		} else if(*ShmTer==0){
			cout << "Numerical integration successful after " << *ShmNev << " function evaluations." <<  endl;
		} else {
			cout << "How did you manage to get here?? Something REALLY went wrong..." << endl;
		}
	
	//output results
	cout << "Results for AD Mom calculation: " << endl;
	output << observable << " is a SCET2 observable" << endl;
	cout << "Anomaly exponent, 1-loop: " << resAD[0] << " +/- " << errAD[0] << ", probability of incorrect error estimate: " << probAD[0] << endl;
	output << "Anomaly exponent, 1-loop: " << resAD[0] << " +/- " << errAD[0] << ", probability of incorrect error estimate: " << probAD[0] << endl;
	cout << "Anomaly exponent, CA term: " << resAD[1] << " +/- " << errAD[1] << ", probability of incorrect error estimate: " << probAD[1] << endl;
	output << "Anomaly exponent, CA term: " << resAD[1] << " +/- " << errAD[1] << ", probability of incorrect error estimate: " << probAD[1] << endl;
	cout << "Anomaly exponent, nf term: " << resAD[2] << " +/- " << errAD[2] << ", probability of incorrect error estimate: " << probAD[2] << endl;
	output << "Anomaly exponent, nf term: " << resAD[2] << " +/- " << errAD[2] << ", probability of incorrect error estimate: " << probAD[2] << endl;
	cout << "Anomaly exponent, Cf term: " << resAD[3] << " +/- " << errAD[3] << ", probability of incorrect error estimate: " << probAD[3] << endl;
	output << "Anomaly exponent, Cf term: " << resAD[3] << " +/- " << errAD[3] << ", probability of incorrect error estimate: " << probAD[3] << endl;

	//detach shared memory
	shmdt(ShmRes);
	shmdt(ShmErr);
	shmdt(ShmProb);
	shmdt(ShmNev);
	shmdt(ShmTer);

	//delete/destroy shared memory
	shmctl(ShmResId, IPC_RMID, 0);
	shmctl(ShmErrId, IPC_RMID, 0);
	shmctl(ShmProbId, IPC_RMID, 0);
	shmctl(ShmNevId, IPC_RMID, 0);
	shmctl(ShmTerId, IPC_RMID, 0);
	return 0;

	//close output file
	output.close();
}
