#include <Input_Parameters.h>

#ifndef AUXILIARIES_H_
#define AUXILIARIES_H_

#ifdef BOOST_H
#include "boost/multiprecision/cpp_dec_float.hpp"
typedef boost::multiprecision::cpp_dec_float_100 decimal;
#endif /* BOOST_H */

#ifdef MPFR_H
#include "boost/multiprecision/mpfr.hpp"
typedef boost::multiprecision::static_mpfr_float_100 decimal;
#endif /* MPFR_H */

#ifdef GMP_H
#include "boost/multiprecision/gmp.hpp"
typedef boost::multiprecision::mpf_float_100 decimal;
#endif /* GMP_H */

#ifdef FLOAT_H
#include "boost/multiprecision/float128.hpp"
typedef boost::multiprecision::float128 decimal;
#endif /* FLOAT_H */

#define EulerGamma 0.577215664901532860606512090082402431042159335939923598805767
#define Zeta3 1.20205690315959428539973816151144999076498629234049888179227
#define Pi 3.14159265358979323846264338327950288419716939937510582097494
#define Zeta5 1.0369277551433699263313654864570341680570809195019

const int ndim2=2;
const int ndim3=3;
const int ndim4=4;
const int ndim5=5;

const int ncomp=15;

decimal tl(double s6);
decimal q(double r);
decimal y(double x);
decimal t5(double s5);
decimal t(double s);
decimal b(double c);
decimal Tk1(decimal t, decimal t5, decimal tl);
decimal Tk2(decimal t, decimal t5, decimal tl);
decimal Ck1(decimal t, decimal t5, decimal tl);
decimal Ck2(decimal t, decimal t5, decimal tl);
decimal Cl(decimal tl);
decimal Ck(decimal tk);

double FA1a(decimal q,decimal y,decimal tl,decimal t,decimal t5,decimal b);
double FA2a(decimal q,decimal y,decimal tl,decimal t,decimal t5,decimal b);
double FA1b(decimal q,decimal y,decimal tl,decimal t,decimal t5,decimal b);
double FA2b(decimal q,decimal y,decimal tl,decimal t,decimal t5,decimal b);

double GAa(decimal r,decimal y,decimal tl,decimal t,decimal tk,decimal b);
double GAb(decimal r,decimal y,decimal tl,decimal t,decimal tk,decimal b);

int D2Int(const int *ndim, const double x[],
const int *ncomp, double F[], void *userdata);

int D3Int(const int *ndim, const double x[],
const int *ncomp, double F[], void *userdata);

int D4Int(const int *ndim, const double x[],
const int *ncomp, double F[], void *userdata);

int D5Int(const int *ndim, const double x[],
const int *ncomp, double F[], void *userdata);

extern const int seed;
extern const int flags;

extern const int maxpass2;
extern const int maxpass3;
extern const int maxpass4;
extern const int maxpass5;

extern const double border;
extern const double maxchisq;
extern const double mindev;

extern const double epsrel2;
extern const double epsabs2;
extern const double epsrel3;
extern const double epsabs3;
extern const double epsrel4;
extern const double epsabs4;
extern const double epsrel5;
extern const double epsabs5;

extern const long long int maxeval2;
extern const long long int maxeval3;
extern const long long int maxeval4;
extern const long long int maxeval5;

extern const int key12;
extern const int key22;
extern const int key32;
extern const int key13;
extern const int key23;
extern const int key33;
extern const int key14;
extern const int key24;
extern const int key34;
extern const int key15;
extern const int key25;
extern const int key35;

inline double ReturnDouble(decimal a) {
	return a.convert_to<double>();
}

#endif /* AUXILIARIES_H_ */
