/*
 * This file contains the difference structures arising from plus distributions tying together the Measurement functions FXi, plus distribution denominators 
 * and contributing remainder/numerator functions XCfEiAj for the 4D integration at all eps-orders and the alpha^-2 order of the Cf^2 structure, subregion a. 
 * Example: I4E0AM2rx ('I'ntegration over '4' dimensions, at 'E'ps to the '0'th and 'A'lpha to the 'M'inus '2'nd order, third and fourth integrations over 
 * 'r' and 'x') contains various logs of FXi functions evaluated at c=0,s5=0, i.e. with the two deltas from the c and s5 +-distributions, multiplied 
 * with the correct X functions' eps- and alpha-powers to arrive at eps^0 alpha^-2. 
 */

#include <4IntAM2.h>
#include <Auxiliaries.h>
#include <cmath>
#include <XFactor.h>
#include <Input_Common.h>

using namespace std;

//need both alpha poles
double I4E0AM2rx(double r, double x, double s, double s6) {
	return 0;
}
double I4E1AM2rx(double r, double x, double s, double s6) {
	return 0;
}
double I4E2AM2rx(double r, double x, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2rc(double c, double r, double s, double s6) {
	return 0;
}
double I4E1AM2rc(double c, double r, double s, double s6) {
	return 0;
}
double I4E2AM2rc(double c, double r, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2rs(double r, double s, double s5, double s6) {
	return 0;
}
double I4E1AM2rs(double r, double s, double s5, double s6) {
	return 0;
}
double I4E2AM2rs(double r, double s, double s5, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2xc(double c, double x, double s, double s6) {
	return 0;
}
double I4E1AM2xc(double c, double x, double s, double s6) {
	return 0;
}
double I4E2AM2xc(double c, double x, double s, double s6) {
	return 0;
}

//need both alpha poles
double I4E0AM2xs(double x, double s, double s5, double s6) {
	return 0;
}
double I4E1AM2xs(double x, double s, double s5, double s6) {
	return 0;
}
double I4E2AM2xs(double x, double s, double s5, double s6) {
	return 0;
}

double I4E0AM2cs(double c, double s, double s5, double s6) {
	return 0; //2 alpha poles, rest leading order
}
double I4E1AM2cs(double c, double s, double s5, double s6) {
	return 8*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*((log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
	        log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE0A0(s,0,s6) +
	     (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
	        log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE0A0(s,s5,s6));
}
double I4E2AM2cs(double c, double s, double s5, double s6) {
	return 8*pow(c,-1)*pow(mexp,-2)*pow(s5,-1)*(2*((-2*log(c)*(log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) +
            log(FA2a(0,0,t(s),0,tl(s6),0)) - log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c)))) +
         log(s5)*(-log(FA1a(0,0,t(s),0,tl(s6),0)) + log(FA1a(0,0,t(s),0,tl(s6),b(c))) - log(FA1b(0,0,t(s),0,tl(s6),0)) + log(FA1b(0,0,t(s),0,tl(s6),b(c))) - log(FA2a(0,0,t(s),0,tl(s6),0)) +
            log(FA2a(0,0,t(s),0,tl(s6),b(c))) - log(FA2b(0,0,t(s),0,tl(s6),0)) + log(FA2b(0,0,t(s),0,tl(s6),b(c)))) + pow(log(FA1a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1a(0,0,t(s),0,tl(s6),b(c))),2) +
         pow(log(FA1b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA1b(0,0,t(s),0,tl(s6),b(c))),2) + pow(log(FA2a(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2a(0,0,t(s),0,tl(s6),b(c))),2) +
         pow(log(FA2b(0,0,t(s),0,tl(s6),0)),2) - pow(log(FA2b(0,0,t(s),0,tl(s6),b(c))),2))*XCfE0A0(s,0,s6) +
      (2*log(c)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) +
            log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c)))) +
         log(s5)*(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) +
            log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) + log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) - log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c)))) -
         pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))),2) -
         pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))),2) - pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),0)),2) + pow(log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))),2))*XCfE0A0(s,s5,s6))\
    + (log(FA1a(0,0,t(s),0,tl(s6),0)) - log(FA1a(0,0,t(s),0,tl(s6),b(c))) + log(FA1b(0,0,t(s),0,tl(s6),0)) - log(FA1b(0,0,t(s),0,tl(s6),b(c))) + log(FA2a(0,0,t(s),0,tl(s6),0)) -
      log(FA2a(0,0,t(s),0,tl(s6),b(c))) + log(FA2b(0,0,t(s),0,tl(s6),0)) - log(FA2b(0,0,t(s),0,tl(s6),b(c))))*XCfE1A0(0,0,s,0,s6) +
   (-log(FA1a(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA1b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA1b(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2a(0,0,t(s),t5(s5),tl(s6),0)) +
      log(FA2a(0,0,t(s),t5(s5),tl(s6),b(c))) - log(FA2b(0,0,t(s),t5(s5),tl(s6),0)) + log(FA2b(0,0,t(s),t5(s5),tl(s6),b(c))))*XCfE1A0(0,0,s,s5,s6));
}
